==> vod-cloud-model-1.0.0-sources.jar: com/valor/vod/cloud/model/database/ddo/MfcCloudPkgDetailDdo.java <==
package com.valor.vod.cloud.model.database.ddo;


import com.valor.vod.common.database.model.AbstractLMI;

import javax.persistence.*;

//网盘包网盘
@Entity
@Table(
    name = "mfc_cloud_pkg_detail",indexes = {
    @Index(name = "i_mfc_cloud_pkg_detail_acct_site",columnList = "acct_site"),
    @Index(name = "i_mfc_cloud_pkg_detail_acct_user_name", columnList = "acct_user_name")
    }
)
public class MfcCloudPkgDetailDdo extends AbstractLMI {

    @Id
    @Column(name = "pkg_id")
    private long pkgId = 0;//资源包ID

    @Id
    @Column(name = "cid")
    private long cid = 0;

    @Column(name = "acct_site")
    private String acctSite;

    @Column(name = "acct_user_name")
    private String acctUserName;

    @Column(name = "acct_login_key")
    private String acctLoginKey;

    @Column(name = "acct_login_type")
    private int acctLoginType;

    @Column(name = "acct_alias")
    private String acctAlias;


    public String getAcctSite() {
        return acctSite;
    }

    public void setAcctSite(String acctSite) {
        this.acctSite = acctSite;
    }

    public String getAcctUserName() {
        return acctUserName;
    }

    public void setAcctUserName(String acctUserName) {
        this.acctUserName = acctUserName;
    }


    public String getAcctAlias() {
        return acctAlias;
    }

    public void setAcctAlias(String acctAlias) {
        this.acctAlias = acctAlias;
    }

    public long getPkgId() {
        return pkgId;
    }

    public void setPkgId(long pkgId) {
        this.pkgId = pkgId;
    }

    public String getAcctLoginKey() {
        return acctLoginKey;
    }

    public void setAcctLoginKey(String acctLoginKey) {
        this.acctLoginKey = acctLoginKey;
    }

    public int getAcctLoginType() {
        return acctLoginType;
    }

    public void setAcctLoginType(int acctLoginType) {
        this.acctLoginType = acctLoginType;
    }

    public long getCid() {
        return cid;
    }

    public void setCid(long cid) {
        this.cid = cid;
    }
}

==> vod-cloud-model-3.1.3-sources.jar: com/valor/vod/cloud/model/database/ddo/MfcCloudPkgDetailDdo.java <==
package com.valor.vod.cloud.model.database.ddo;


import com.valor.vod.common.database.model.AbstractLMI;

import javax.persistence.*;

//网盘包网盘
@Entity
@Table(
    name = "mfc_cloud_pkg_detail",indexes = {
    @Index(name = "i_mfc_cloud_pkg_detail_acct_site",columnList = "acct_site"),
    @Index(name = "i_mfc_cloud_pkg_detail_acct_user_name", columnList = "acct_user_name")
    }
)
public class MfcCloudPkgDetailDdo extends TenantAbstractLMI {

    @Id
    @Column(name = "pkg_id")
    private long pkgId = 0;//资源包ID

    @Id
    @Column(name = "cid")
    private long cid = 0;

    @Column(name = "acct_site")
    private String acctSite;

    @Column(name = "acct_user_name")
    private String acctUserName;

    @Column(name = "acct_login_key")
    private String acctLoginKey;

    @Column(name = "acct_login_type")
    private int acctLoginType;

    @Column(name = "acct_alias")
    private String acctAlias;


    public String getAcctSite() {
        return acctSite;
    }

    public void setAcctSite(String acctSite) {
        this.acctSite = acctSite;
    }

    public String getAcctUserName() {
        return acctUserName;
    }

    public void setAcctUserName(String acctUserName) {
        this.acctUserName = acctUserName;
    }


    public String getAcctAlias() {
        return acctAlias;
    }

    public void setAcctAlias(String acctAlias) {
        this.acctAlias = acctAlias;
    }

    public long getPkgId() {
        return pkgId;
    }

    public void setPkgId(long pkgId) {
        this.pkgId = pkgId;
    }

    public String getAcctLoginKey() {
        return acctLoginKey;
    }

    public void setAcctLoginKey(String acctLoginKey) {
        this.acctLoginKey = acctLoginKey;
    }

    public int getAcctLoginType() {
        return acctLoginType;
    }

    public void setAcctLoginType(int acctLoginType) {
        this.acctLoginType = acctLoginType;
    }

    public long getCid() {
        return cid;
    }

    public void setCid(long cid) {
        this.cid = cid;
    }
}
